Files
TheRock/rocm-systems/projects/hip-tests/catch/unit/executionControl/launch_api.cc
T
derek.holloway 7502bf64a4
CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
Flatten subprojects into a single base monorepo
2026-09-02 16:34:47 -07:00

74 lines
2.0 KiB
C++

/*
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
*
* SPDX-License-Identifier: MIT
*/
#include "execution_control_common.hh"
#include <hip_test_common.hh>
#include <resource_guards.hh>
HIP_TEST_CASE(Unit_hipLaunchByPtr_Positive_Basic) {
LinearAllocGuard<int> alloc(LinearAllocs::hipMallocManaged, 4);
SECTION("hipConfigureCall") { HIP_CHECK(hipConfigureCall(dim3{1}, dim3{1}, 0, nullptr)); }
SECTION("__hipPushCallConfiguration") {
HIP_CHECK(__hipPushCallConfiguration(dim3{1}, dim3{1}, 0, nullptr));
}
int* arg = alloc.ptr();
HIP_CHECK(hipSetupArgument(&arg, sizeof(int*), 0));
HIP_CHECK(hipLaunchByPtr(reinterpret_cast<void*>(kernel_42)));
HIP_CHECK(hipDeviceSynchronize());
REQUIRE(alloc.ptr()[0] == 42);
}
HIP_TEST_CASE(Unit_hipLaunchByPtr_Negative_Parameters) {
HIP_CHECK(hipConfigureCall(dim3{1}, dim3{1}, 0, nullptr));
HIP_CHECK_ERROR(hipLaunchByPtr(nullptr), hipErrorInvalidDeviceFunction);
}
HIP_TEST_CASE(Unit___hipPushCallConfiguration_Positive_Basic) {
StreamGuard stream_guard(Streams::created);
HIP_CHECK(__hipPushCallConfiguration(dim3{1, 2, 3}, dim3{3, 2, 1}, 1024, stream_guard.stream()));
dim3 grid;
dim3 block;
size_t shmem;
hipStream_t stream;
HIP_CHECK(__hipPopCallConfiguration(&grid, &block, &shmem, &stream));
REQUIRE(grid.x == 1);
REQUIRE(grid.y == 2);
REQUIRE(grid.z == 3);
REQUIRE(block.x == 3);
REQUIRE(block.y == 2);
REQUIRE(block.z == 1);
REQUIRE(shmem == 1024);
REQUIRE(stream == stream_guard.stream());
}
HIP_TEST_CASE(Unit_hipLaunchByPtr_Verify_Capture) {
LinearAllocGuard<int> alloc(LinearAllocs::hipMallocManaged, 4);
hipStream_t stream;
HIP_CHECK(hipStreamCreate(&stream));
GENERATE_CAPTURE();
BEGIN_CAPTURE(stream);
HIP_CHECK(hipConfigureCall(dim3{1}, dim3{1}, 0, stream));
int* arg = alloc.ptr();
HIP_CHECK(hipSetupArgument(&arg, sizeof(int*), 0));
HIP_CHECK(hipLaunchByPtr(reinterpret_cast<void*>(kernel_42)));
END_CAPTURE(stream);
HIP_CHECK(hipDeviceSynchronize());
HIP_CHECK(hipStreamDestroy(stream));
REQUIRE(alloc.ptr()[0] == 42);
}